@@ -604,7 +604,7 @@ class CreateServer(command.ShowOne):
             type=_prefix_checked_value('port-id='),
             help=_("Create a NIC on the server and connect it to port. "
                    "Specify option multiple times to create multiple NICs. "
-                   "This is a wrapper for the '--nic port-id=<pord>' "
+                   "This is a wrapper for the '--nic port-id=<port>' "
                    "parameter that provides simple syntax for the standard "
                    "use case of connecting a new server to a given port. For "
                    "more advanced use cases, refer to the '--nic' parameter."),
@@ -999,13 +999,9 @@ class DeleteServer(command.Command):
                 compute_client.servers, server)
             compute_client.servers.delete(server_obj.id)
             if parsed_args.wait:
-                if utils.wait_for_delete(
-                    compute_client.servers,
-                    server_obj.id,
-                    callback=_show_progress,
-                ):
-                    self.app.stdout.write('\n')
-                else:
+                if not utils.wait_for_delete(compute_client.servers,
+                                             server_obj.id,
+                                             callback=_show_progress):
                     LOG.error(_('Error deleting server: %s'),
                               server_obj.id)
                     self.app.stdout.write(_('Error deleting server\n'))
@@ -1030,7 +1026,9 @@ class ListServer(command.Lister):
         parser.add_argument(
             '--ip6',
             metavar='<ip-address-regex>',
-            help=_('Regular expression to match IPv6 addresses'),
+            help=_('Regular expression to match IPv6 addresses. Note '
+                   'that this option only applies for non-admin users '
+                   'when using ``--os-compute-api-version`` 2.5 or greater.'),
         )
         parser.add_argument(
             '--name',
@@ -1321,6 +1319,14 @@ class ListServer(command.Lister):
         # Populate image_name, image_id, flavor_name and flavor_id attributes
         # of server objects so that we can display those columns.
         for s in data:
+            if compute_client.api_version >= api_versions.APIVersion('2.69'):
+                # NOTE(tssurya): From 2.69, we will have the keys 'flavor'
+                # and 'image' missing in the server response during
+                # infrastructure failure situations.
+                # For those servers with partial constructs we just skip the
+                # processing of the image and flavor informations.
+                if not hasattr(s, 'image') or not hasattr(s, 'flavor'):
+                    continue
             if 'id' in s.image:
                 image = images.get(s.image['id'])
                 if image:
@@ -1588,11 +1594,34 @@ class RebuildServer(command.ShowOne):
             metavar='<password>',
             help=_("Set the password on the rebuilt instance"),
         )
+        parser.add_argument(
+            '--property',
+            metavar='<key=value>',
+            action=parseractions.KeyValueAction,
+            help=_('Set a property on the rebuilt instance '
+                   '(repeat option to set multiple values)'),
+        )
         parser.add_argument(
             '--wait',
             action='store_true',
             help=_('Wait for rebuild to complete'),
         )
+        key_group = parser.add_mutually_exclusive_group()
+        key_group.add_argument(
+            '--key-name',
+            metavar='<key-name>',
+            help=_("Set the key name of key pair on the rebuilt instance."
+                   " Cannot be specified with the '--key-unset' option."
+                   " (Supported by API versions '2.54' - '2.latest')"),
+        )
+        key_group.add_argument(
+            '--key-unset',
+            action='store_true',
+            default=False,
+            help=_("Unset the key name of key pair on the rebuilt instance."
+                   " Cannot be specified with the '--key-name' option."
+                   " (Supported by API versions '2.54' - '2.latest')"),
+        )
         return parser
 
     def take_action(self, parsed_args):
@@ -1613,7 +1642,21 @@ class RebuildServer(command.ShowOne):
             'image', {}).get('id')
         image = utils.find_resource(image_client.images, image_id)
 
-        server = server.rebuild(image, parsed_args.password)
+        kwargs = {}
+        if parsed_args.property:
+            kwargs['meta'] = parsed_args.property
+
+        if parsed_args.key_name or parsed_args.key_unset:
+            if compute_client.api_version < api_versions.APIVersion('2.54'):
+                msg = _('--os-compute-api-version 2.54 or later is required')
+                raise exceptions.CommandError(msg)
+
+        if parsed_args.key_unset:
+            kwargs['key_name'] = None
+        if parsed_args.key_name:
+            kwargs['key_name'] = parsed_args.key_name
+
+        server = server.rebuild(image, parsed_args.password, **kwargs)
         if parsed_args.wait:
             if utils.wait_for_status(
                 compute_client.servers.get,
